pub struct FRIOracleProver<F, C>where
F: Field,{ /* private fields */ }Expand description
The ProxTestOracleProver for a FRI-style code proximity check.
Implementations
Sourceimpl<F, C> FRIOracleProver<F, C>where
F: Field,
impl<F, C> FRIOracleProver<F, C>where
F: Field,
Sourcepub const fn new(
codeword: FieldBuffer<F>,
commitment: C,
coset_log_size: usize,
) -> Self
pub const fn new( codeword: FieldBuffer<F>, commitment: C, coset_log_size: usize, ) -> Self
Constructs a new oracle prover wrapping a committed fold-round codeword.
coset_log_size is the base-2 log of the coset size of the fold that consumes this
codeword, which must equal the commitment’s leaf size.